==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/TimeRangeFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TimeRangeFluent<A extends TimeRangeFluent<A>> extends BaseFluent<A>{
  public TimeRangeFluent() {
  }
  public TimeRangeFluent(TimeRange instance) {
    instance = (instance != null ? instance : new TimeRange());

    if (instance != null) {
      this.withEndTime(instance.getEndTime());
      this.withStartTime(instance.getStartTime());
      this.withEndTime(instance.getEndTime());
      this.withStartTime(instance.getStartTime());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String endTime;
  private String startTime;
  private Map<String,Object> additionalProperties;
  public String getEndTime() {
    return this.endTime;
  }
  public A withEndTime(String endTime) {
    this.endTime=endTime; return (A) this;
  }
  public boolean hasEndTime() {
    return this.endTime != null;
  }
  public String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public boolean hasStartTime() {
    return this.startTime != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimeRangeFluent that = (TimeRangeFluent) o;
    if (!java.util.Objects.equals(endTime, that.endTime)) return false;

    if (!java.util.Objects.equals(startTime, that.startTime)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(endTime,  startTime,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (endTime != null) { sb.append("endTime:"); sb.append(endTime + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-monitoring-6.9.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/TimeRangeFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TimeRangeFluent<A extends TimeRangeFluent<A>> extends BaseFluent<A>{
  public TimeRangeFluent() {
  }
  
  public TimeRangeFluent(TimeRange instance) {
    this.copyInstance(instance);
  }
  private String endTime;
  private String startTime;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(TimeRange instance) {
    instance = (instance != null ? instance : new TimeRange());
    if (instance != null) {
          this.withEndTime(instance.getEndTime());
          this.withStartTime(instance.getStartTime());
          this.withEndTime(instance.getEndTime());
          this.withStartTime(instance.getStartTime());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getEndTime() {
    return this.endTime;
  }
  
  public A withEndTime(String endTime) {
    this.endTime = endTime;
    return (A) this;
  }
  
  public boolean hasEndTime() {
    return this.endTime != null;
  }
  
  public String getStartTime() {
    return this.startTime;
  }
  
  public A withStartTime(String startTime) {
    this.startTime = startTime;
    return (A) this;
  }
  
  public boolean hasStartTime() {
    return this.startTime != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TimeRangeFluent that = (TimeRangeFluent) o;
    if (!java.util.Objects.equals(endTime, that.endTime)) return false;
    if (!java.util.Objects.equals(startTime, that.startTime)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(endTime,  startTime,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (endTime != null) { sb.append("endTime:"); sb.append(endTime + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
